import { dataSource } from "../data-source";
import { executivePosition } from "../entity/executivePosition";
import { user } from "../entity/user";
import InternalException from "../exceptions/internalException";

export default abstract class ExecutivePositionService {
  /**
   * @description get all executivePositions
   * @returns {Promise<Array<executivePosition>>}
   */
  static async getAll(): Promise<Array<executivePosition>> {
    return await dataSource
      .getRepository(executivePosition)
      .createQueryBuilder("executivePosition")
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new InternalException("executivePositions not found", err);
      });
  }

  /**
   * @description get executivePosition by id
   * @returns {Promise<executivePosition>}
   */
  static async getById(id: number): Promise<executivePosition> {
    return await dataSource
      .getRepository(executivePosition)
      .createQueryBuilder("executivePosition")
      .andWhere("executivePosition.id = :id", { id: id })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new InternalException("executivePosition not found by id", err);
      });
  }

  // /**
  //  * @description get members assigned to executivePosition
  //  * @returns {Promise<Array<user>>}
  //  */
  // static async getMembersByexecutivePositionId(id: number): Promise<Array<member>> {
  //   return await dataSource
  //     .getRepository(executivePosition)
  //     .createQueryBuilder("executivePosition")
  //     .leftJoinAndSelect("executivePosition.members", "members")
  //     .andWhere("executivePosition.id = :id", { id: id })
  //     .getOneOrFail()
  //     .then((res) => {
  //       return [];
  //     })
  //     .catch(() => {
  //       throw new InternalException("executivePosition assigned members not found by id");
  //     });
  // }
}
